<ion-view view-title="{{'About Mopidy Mobile' | translate}}">
  <ion-content class="padding">
    <img src="images/icon.png" style="float: left; margin-right:10px">
    <div>
      <h2>Mopidy Mobile</h2>
      <span translate translate-values="{version: version}">
        Version {version}
      </span>
    </div>

    <p style="clear: both;"></p>

    <p>
      Copyright &copy; 2015 Thomas Kemmer.
      <br>
      <a href="#" ng-click="open('https://github.com/tkem/mopidy-mobile')">
        https://github.com/tkem/mopidy-mobile
      </a>
    </p>
    <p>
      <span translate>Licensed under the</span>
      <a href="#" ng-click="open('https://github.com/tkem/mopidy-mobile/blob/master/LICENSE')">Apache License, Version 2.0</a>.
    </p>

    <p translate>
      Mopidy Mobile makes use of the following libraries, fonts and frameworks:
    </p>

    <p>
      <a href="#" ng-click="open('https://docs.mopidy.com/en/latest/api/js/')">
        <h3>Mopidy.js</h3>
      </a>
      Copyright &copy; 2015 Stein Magnus Jodal and contributors.
      <br>
      <a href="#" ng-click="open('https://github.com/mopidy/mopidy.js/blob/master/LICENSE')">
        Apache License, Version 2.0
      </a>
    </p>

    <p>
      <a href="#" ng-click="open('http://ionicframework.com/')">
        <h3>Ionic</h3>
      </a>
      Copyright &copy; 2014 Drifty Co.
      <br>
      <a href="#" ng-click="open('https://github.com/driftyco/ionic/blob/master/LICENSE')">
        MIT License
      </a>
    </p>

    <div ng-if="cordova">
      <p>
        <a href="#" ng-click="open('http://cordova.apache.org/')">
          <h3>Apache Cordova</h3>
        </a>
        Copyright &copy; 2012, 2013 The Apache Software Foundation.
        <br>
        <a href="#" ng-click="open('http://www.apache.org/licenses/LICENSE-2.0')">
          Apache License, Version 2.0
        </a>
      </p>

      <p>
        <a href="#" ng-click="open('https://github.com/whiteoctober/cordova-plugin-app-version')">
          <h3>Cordova AppVersion Plugin</h3>
        </a>
        Copyright &copy; 2013 White October
        <br>
        <a href="#" ng-click="open('https://github.com/whiteoctober/cordova-plugin-app-version/blob/develop/LICENSE')">
          MIT License
        </a>
      </p>
    </div>

    <p>
      <a href="#" ng-click="open('https://angularjs.org/')">
        <h3>AngularJS</h3>
      </a>
      Copyright &copy; 2010-2015 Google, Inc.
      <br>
      <a href="#" ng-click="open('https://github.com/angular/angular.js/blob/master/LICENSE')">
        MIT License
      </a>
    </p>

    <p>
      <a href="#" ng-click="open('http://angular-ui.github.io/ui-router/')">
        <h3>AngularUI Router</h3>
      </a>
      Copyright &copy; 2013-2015 The AngularUI Team, Karsten Sperling.
      <br>
      <a href="#" ng-click="open('https://github.com/angular-ui/ui-router/blob/master/LICENSE')">
        MIT License
      </a>
    </p>

    <p>
      <a href="#" ng-click="open('http://angular-translate.github.io/')">
        <h3>angular-translate</h3>
      </a>
      Copyright &copy; 2014 &lt;pascal.precht@gmail.com&gt;.
      <br>
      <a href="#" ng-click="open('https://github.com/angular-translate/angular-translate/blob/master/LICENSE')">
        MIT License
      </a>
    </p>

    <p>
      <a href="#" ng-click="open('https://icomoon.io/')">
        <h3>IcoMoon-Free</h3>
      </a>
      Copyright &copy; 2014 Keyamoon.
      <br>
      <a href="#" ng-click="open('https://github.com/layerssss/icomoon-bower/blob/master/license.txt')">
        CC BY 3.0
      </a>
    </p>

  </ion-content>
</ion-view>
